<?php

class Class_v4_wp1crm_Extensions_EM_WC
{
    public function __construct()
    {
        add_action('init', [$this, 'init']);
        add_action('wp_loaded', [$this, 'wp_loaded'], 20);

        return $this;
    }

    public function init()
    {
        if (!defined('EM_WC_DIR')) {
            return;
        }

        // show reduced woocommerce price
        add_filter('em_locate_template', [$this, 'relocate_em_templates'], 20, 2);
        add_filter('em_ticket_get_price', [$this, 'em_ticket_get_woo_price'], 10, 2);
    }

    public function wp_loaded()
    {
        if (!defined('EM_WC_DIR')) {
            return;
        }

        self::add_endpoints();
        add_filter('woocommerce_account_menu_items', [$this, 'menu_items']);
        add_action('woocommerce_account_my-bookings_endpoint', [$this, 'my_bookings_endpoint']);

        remove_filter(
            'em_event_output_placeholder',
            'Events_Manager_WooCommerce\Bookings_Form::em_event_output_placeholder',
            10
        );
        remove_action('init', 'Events_Manager_WooCommerce\Endpoints::add_endpoints');
        remove_filter('woocommerce_account_menu_items', 'Events_Manager_WooCommerce\Endpoints::menu_itms');
        remove_action(
            'woocommerce_account_my-bookings_endpoint',
            'Events_Manager_WooCommerce\Endpoints::my_bookings_endpoint'
        );
    }

    public function em_ticket_get_woo_price($price, $EM_Ticket)
    {
        try {
            $product_id = Events_Manager_WooCommerce\Product::get_ticket_product_id($EM_Ticket);
            // check if product has discount
            $product = wc_get_product($product_id);
            $price = $product->get_price();
        } catch (WC_Data_Exception $e) {
            // do nothing. use EM price
        }

        return $price;
    }

    public function relocate_em_templates($located, $template_name)
    {
        // child theme has priority
        $theme_located = locate_template(array('plugins/events-manager/' . $template_name));

        if ($theme_located) {
            $located = $theme_located;
        } else {
            switch ($template_name) {
                case 'forms/bookingform/tickets-list.php':
                    $located = __DIR__ . '/partials/oauth/em-wc/forms/bookingform/tickets-list.php';
                    break;
            }
        }

        return $located;
    }

    /**
     * Add endpoints
     */
    public static function add_endpoints()
    {
        add_rewrite_endpoint('my-bookings', EP_ROOT | EP_PAGES);
    }

    /**
     * Add 'My Bookings' menu item to WC my account page.
     * @param $items
     * @return array
     */
    public static function menu_items($items)
    {
        $orders_pos = 2;
        $items_start = array_splice($items, $orders_pos);
        $items['my-bookings'] = __('Bookings', 'events-manager');
        return $items + $items_start;
    }

    /**
     * Outputs the my bookings page endpoint content
     */
    public static function my_bookings_endpoint()
    {
        em_my_bookings();
    }

    /**
     * Add a bookings button for this order, so user can see summary of bookings in more detail via EM.
     * Not implemented yet, just a POC with code in-place, needs revisint.
     * @param $actions
     * @param $order
     * @return mixed
     */
    public static function order_buttons($actions, $order)
    {
        /* @var \WC_Order $order */
        if ($order->get_status() == 'completed') {
            foreach ($order->get_items() as $item) {
                $data = $item->get_data();
                if (!empty($data['booking'])) {
                    // we have a booking here, so add the 'bookings' button
                    $actions['my-bookings'] = array(
                        'url' => wc_get_endpoint_url('my-bookings', $order->get_id()),
                        'name' => __('My Bookings', 'events-manager')
                    );
                    break;
                }
            }
        }
        return $actions;
    }
}
