<?php

if (!class_exists('v4_wp1crm_Extensions_Updater')) {

    class v4_wp1crm_Extensions_Updater
    {
//      private $plugin_version = '';
        private $package_type = 'wp-plugins';
        private $plugins = [
            'v4-selfservice' => 'v4-selfservice/v4-selfservice.php',
            'v4-wp1crm-extensions' => 'v4-wp1crm-extensions/v4-wp1crm-extensions.php',
            'v4-wp-webhook' => 'v4-wp-webhook/v4-wp-webhook.php',
            'v4-sepa' => 'v4-sepa/v4-sepa.php',
            'v4-portal' => 'v4-portal/v4-portal.php',
            'v4-oauth' => 'v4-oauth/v4oAuth.php',
            'v4-formidable-file-output' => 'v4-formidable-file-output/v4-formidable-file-output.php',
            'v4-formidable-api-response' => 'v4-formidable-api-response/v4-formidable-api-response.php',
        ];
        private $domain = 'https://updates.wp3.visual4.com';
        private $cache_allowed = false;
        private $licencetest = 'T35T-K3Y1';

        public function __construct()
        {
            add_filter('plugins_api', array($this, 'info'), 20, 3);
//          add_filter('site_transient_update_plugins', array($this, 'check'));
            add_filter('pre_set_site_transient_update_plugins', array($this, 'check'), 21, 1);
            add_action('upgrader_process_complete', array($this, 'purge'), 10, 2);
            foreach ($this->plugins as $plugin) {
                add_action('in_plugin_update_message-' . $plugin, array($this, 'licence_message'), 10, 2);
            }
        }

        public function request($plugin_key)
        {
            $remote = get_transient($plugin_key);

            if (false === $remote || !$this->cache_allowed) {
                $remote = wp_remote_get(
                    add_query_arg(
                        array(
                            // v4 to do: licence key?
                            'type' => $this->package_type,
                            'slug' => $plugin_key,
                            'license_key' => urlencode($this->licencetest)
                        ),
                        $this->domain . '/v4-updater.php'
                    ),
                    array(
                        'timeout' => 10,
                        'headers' => array(
                            'Accept' => 'application/json'
                        )
                    )
                );

                if (is_wp_error($remote)
                    || 200 !== wp_remote_retrieve_response_code($remote)
                    || empty(wp_remote_retrieve_body($remote))
                ) {
                    return false;
                }

                set_transient($plugin_key, $remote, DAY_IN_SECONDS);
            }

            return json_decode(wp_remote_retrieve_body($remote));
        }

        function info($res, $action, $args)
        {
            // do nothing if you're not getting plugin information right now
            if ('plugin_information' !== $action) {
                return false;
            }

            // do nothing if it is not our plugin
            if (!in_array($args->slug, array_keys($this->plugins))) {
                return false;
            }

            // get updates
            $remote = $this->request($args->slug);

            if (!$remote) {
                return false;
            }

            $res = new \stdClass();

            $res->name = $remote->name ?? '';
            $res->slug = $remote->slug ?? '';
            $res->version = $remote->version ?? '';
            $res->tested = $remote->tested ?? '';
            $res->requires = $remote->requires ?? '';
            $res->author = is_array($remote->author) ? implode(', ', $remote->author) : $remote->author ?? '';
            $res->author_profile = $remote->author_homepage ?? '';
            $res->download_link = $remote->download_link ?? '';
            $res->trunk = $remote->download_link ?? '';
            $res->requires_php = $remote->requires_php ?? '';
            $res->last_updated = $remote->last_updated ?? '';

            $res->sections = array(
                'changelog' => $remote->sections->changelog, // changelog tab
            );

            if (!empty($remote->banners)) {
                $res->banners = array(
                    'low' => $remote->banners->low,
                    'high' => $remote->banners->high
                );
            }

            return $res;
        }

        public function check($transient)
        {
            if (empty($transient->checked)) {
                return $transient;
            }

            foreach ($this->plugins as $plugin_key => $plugin) {
                //check if plugins are installed
                if (!is_dir(ABSPATH . 'wp-content/plugins/' . $plugin_key)) {
                    continue;
                }

                $remote = $this->request($plugin_key);

                if ($remote) {
                    $res = new \stdClass();
//              $res->id = '?';
                    $res->slug = $plugin_key;
                    $res->plugin = $plugin;
                    $res->new_version = $remote->version ?? '';
                    $res->tested = $remote->tested;
                    $res->upgrade_notice = $remote->upgrade_notice ?? '';
                    $res->url = $remote->url ?? '';
                    $res->requires_php = $remote->php_version ?? '';

                    //check for git
                    $has_git = false;
                    $plugin_dir = scandir(ABSPATH . 'wp-content/plugins/' . $plugin_key);
                    foreach ($plugin_dir as $item) {
                        if ($item === '.git') {
                            $has_git = true;
                        }
                    }
                    if ($has_git) {
                        $res->package = '';
                        $res->upgrade_notice = 'WARNING! GIT found. Update is deactivated. Please update via git pull.';
                    } else {
                        $res->package = $remote->download_link;
                    }

                    $plugin_data = get_plugin_data(ABSPATH . 'wp-content/plugins/' . $plugin);
                    $plugin_version = $plugin_data['Version'];

                    if (version_compare($plugin_version, $remote->version, '<')
                        && version_compare($remote->requires, get_bloginfo('version'), '<')
                    ) {
                        $transient->response[$res->plugin] = $res;
                        unset($transient->no_update[$res->plugin]);
                    } else {
                        $transient->no_update[$res->plugin] = $res;
                        unset($transient->response[$res->plugin]);
                    }
                }
            }

            return $transient;
        }

        public function purge($upgrader_object, $options)
        {
            if ($this->cache_allowed
                && 'update' === $options['action']
                && 'plugin' === $options['type']
            ) {
                // just clean the cache when new plugin version is installed
                delete_transient($plugin_key);
            }
        }

        public function licence_message($plugin_info_array, $plugin_info_object)
        {
            if (empty($plugin_info_array['package'])) {
                // v4 to do: plugin translation
                echo '<br><i>' . 'Please contact our support team at' . ' <a href="https://visual4.de/kontakt/" target="_blank">visual4</a>.</i>';
            }
            if (!empty($plugin_info_array['upgrade_notice'])) {
                echo '<br><i>' . $plugin_info_array['upgrade_notice'] . '</i>';
            }
        }
    }

}
