(function ($) {
	'use strict';

	/**
	 * @var {object} v4_wp1crm_extensions
	 * @property {string} required - '<abbr class="required" title="' . esc_attr__( 'required', 'woocommerce' ) . '">*</abbr>',
	 * @property {string} optional - '<span class="optional">(' . esc_html__( 'optional', 'woocommerce' ) . ')</span>',
	 * @property {string} attend_myself - esc_html__( 'I will attend the event myself', 'v4-wp1crm-extensions' ),
	 * @property {bool} is_user_logged_in - is_user_logged_in(),
	 * @property {object} current_user
	 * @property {string} current_user.email' - email
	 * @property {string} current_user.first_name' - first_name
	 * @property {string} current_user.last_name' - last_name
	 * @property {string} current_user.salutation' - salutation
	 * @property {string} current_user.primary_address_street' - primary_address_street
	 * @property {string} current_user.primary_address_city' - primary_address_city
	 * @property {string} current_user.primary_address_postalcode' - primary_address_postalcode
	 * @property {string} current_user.primary_address_country' - primary_address_country
	 */

	$(document).ready(function () {

		if ($('form.woocommerce-checkout').length > 0) {
			const $billing_country = $('#billing_country'),
				country = $billing_country.val(),
				ust_wrapper = $('#tax_information_field');
			v4_change_ust_required_status(ust_wrapper, country);

			//tax_information
			$billing_country.on('change', function () {
				const country = $(this).val(),
					ust_wrapper = $('#tax_information_field');

				v4_change_ust_required_status(ust_wrapper, country);
			});
		}

		/*
			EM
		 */

		let em_booking_form = $('.em-booking-form');
		let em_booking_form_toggle = $('.em-booking-form-toggle');

		if (em_booking_form_toggle.length > 0) {
			em_booking_form.stop().hide();
			em_booking_form_toggle.on('click', function (e) {
				e.preventDefault();
				em_booking_form.stop().slideToggle();
			});
		}


		if (v4_wp1crm_extensions.is_user_logged_in) {
			em_booking_form.find('.em-tickets').on('change', function () {
				let ticket_bookings = $('.em-ticket-bookings');
				let tickets_counter = 0;
				ticket_bookings.each(function () {
					tickets_counter++;
					let ticket_booking = $(this).find('.em-ticket-booking').first();
					if (ticket_booking.find('.wpwh_myself').length === 0) {
						let wpwh_myself = '<label for="wpwh_myself-' + tickets_counter + '"><input id="wpwh_myself-' + tickets_counter + '" class="wpwh_myself" type="checkbox" value="1">&nbsp;' +
							v4_wp1crm_extensions.attend_myself +
							'</label>';
						ticket_booking.first().prepend(wpwh_myself);

						$('input.wpwh_myself:checkbox').change(function () {
							let checked = $(this).is(':checked');
							let mapping = {
								email: ['email1', 'attendee_email', 'attendee_email1'],
								first_name: ['attendee_first_name'],
								last_name: ['attendee_last_name'],
								salutation: ['attendee_salutation'],
								company: ['attendee_company'],
								phone: ['attendee_phone'],
								primary_address_street: ['attendee_primary_address_street'],
								primary_address_city: ['attendee_primary_address_city'],
								primary_address_country: ['attendee_primary_address_country'],
								primary_address_postalcode: ['attendee_primary_address_postalcode'],
							};

							$(this).closest('.em-ticket-booking').find('input,select').each(function () {
								for (let key in mapping) {
									for (let i = 0; i < mapping[key].length; i++) {
										if (this.name.includes('[' + key + ']') || this.name.includes('[' + mapping[key][i] + ']')) {
											if ($(this).value !== "" && checked) {
												if (v4_wp1crm_extensions.current_user[key]) {
													$(this)
														.attr('readonly', 'readonly')
														.val(v4_wp1crm_extensions.current_user[key]);
												}
											} else {
												$(this)
													.removeAttr('readonly')
													.val('');
											}
										}
									}
								}
								if (this.name.includes('[name]') || this.name.includes('[attendee_name]')) {
									if (checked)
										$(this)
											.attr('readonly', 'readonly')
											.val(v4_wp1crm_extensions.current_user.first_name + ' ' + v4_wp1crm_extensions.current_user.last_name);
									else
										$(this)
											.removeAttr('readonly')
											.val('');
								}
							});
						});
					}
				});
			});
			em_booking_form.trigger('change');

		}
	});

	/**
	 * @param ust_wrapper
	 * @param country
	 */
	const v4_change_ust_required_status = function (ust_wrapper, country) {
		if (typeof (v4_wp1crm_extensions) === "undefined" || v4_wp1crm_extensions === null)
			return;

		if (country === "DE") {
			ust_wrapper
				.find('abbr.required')
				.after(v4_wp1crm_extensions.optional)
				.remove();
		} else {
			ust_wrapper
				.find('span.optional')
				.after(v4_wp1crm_extensions.required)
				.remove();
		}
	}

})(jQuery);
